powered by
This method is designed to remove the dummy tip added to a dataset before running with Mr. Bayes.
drop.dummy.mb( tree.file, output.file = NULL, dummy.name = "dummy", convert.ages = TRUE )
list of tree converted tree (as treedata) ; and offset age of the youngest tip in the final tree
tree
offset
path to file containing the tree with dummy tip
path to file to write converted tree. If NULL (default), the tree is simply returned.
NULL
name of the added dummy tip, default dummy.
dummy
whether height metadata should be converted to height - offset (required to plot e.g. HPD intervals correctly). Default TRUE.
drop.dummy.beast() for the same function using summary trees with a "dummy" extant from BEAST2
drop.dummy.beast()
# Remove the dummy tip from the summary tree final_tree <- drop.dummy.mb(system.file("extdata", "tree_mb_dummy.tre", package = "EvoPhylo"))
Run the code above in your browser using DataLab