Learn R Programming

EvoPhylo (version 0.3.5)

tree3p: Phylogenetic tree with 3 clock partitions

Description

A clock Bayesian phylogenetic tree, imported as an S4 class object using treeio::read.mrbayes().

Usage

data("tree3p")

Arguments

Format

A tidytree object.

Details

This example tree file was produced by analyzing the data set with 3 morphological clock partitions from Simões & Pierce (2021).

References

Simões, T. R. and S. E. Pierce (2021). Sustained High Rates of Morphological Evolution During the Rise of Tetrapods. Nature Ecology & Evolution 5: 1403–1414.

See Also

tree1p for another tree object with a single clock partition.

get_clockrate_table_MrBayes for extratcing the poserior clockrates from a tree object.