vignette("fbd-params") for the use of this function as part of an analysis pipeline.
combine_log for producing a single data set of parameter posterior samples from individual parameter log files.
FBD_reshape for converting posterior parameter table from wide to long format.
FBD_dens_plot, FBD_normality_plot, FBD_tests1, and FBD_tests2 for other functions used to summarize and display the distributions of the parameter posteriors.
pairwise.t.test and pairwise.wilcox.test for the tests used.