A data frame containing a row for each clade and each clock with summary statistics (n, mean, standard deviation, minimum, 1st quartile, median, third quartile, maximum).
Arguments
rate_table
A data frame of clock rates, such as from the output of get_clockrate_table_MrBayes with an extra "clade" column.
file
An optional file path where the resulting table will be stored using write.csv.
digits
The number of digits to round the summary results to. Default is 3. See round.
Details
The user must manually add clades to the rate table produced by get_clockrate_table_MrBayes before it can be used with this function. This can be doen manually within R, such as by using a graphical user interface for editing data like the DataEditR package, or by writing the rate table to a spreadsheet and reading it back in after adding the clades. The example below uses a table that has had the clades added.
See Also
vignette("rates-selection") for the use of this function as part of an analysis pipeline.
# See vignette("rates-selection") for how to use this# function as part of an analysis pipelinedata("RateTable_Means_3p_Clades")
clockrate_summary(RateTable_Means_3p_Clades)